@@ -1,13 +1,12 @@
 use std::thread::current;
-use elikar::{Elikar, States, common::Spawner};
-use futures::StreamExt;
-use xecs::system::System;
+use elikar::Spawner;
+use futures::stream::StreamExt;
 
 fn main() {
     // use simple_logger::SimpleLogger;
     // SimpleLogger::new().init().unwrap();
 
-    let mut game = Elikar::new().unwrap();
+    let mut game = elikar::init().unwrap();
 
     println!("main thread:{:?}",current().id());
 
@@ -18,23 +17,19 @@ fn main() {
     let events = game.events(); 
     game.spawn(async move{
         let mut quit = events.on_quit();
-        let world = quit.world();
         if let Some(_) = quit.next().await {
-            let world = world.read();
-            let mut states = world.resource_write::<States>().unwrap();
-            states.quit();
+            events.elikar_world().quit();
         }
     });
 
     let events = game.events(); 
     game.spawn(async move{
         let mut mouse_down = events.on_mouse_down();
-        let world = mouse_down.world();
         while let Some(button) = mouse_down.next().await {
             println!("button down:{:?}",button);
-            let world = world.read();
-            let states = world.resource_read::<States>().unwrap();
-            println!("fps:{},actual_fps:{}",states.fps(),states.actual_fps());
+            let world = events.elikar_world();
+            let time = world.time();
+            println!("fps:{},actual_fps:{}",time.fps(),time.actual_fps());
         }
     });
     let events = game.events(); 
