@@ -1,21 +1,16 @@
-use elikar::{Elikar, States, common::Spawner};
+use elikar::Spawner;
 use futures::StreamExt;
-use xecs::system::System;
-
 
 fn main() {
-    let mut game = Elikar::new().unwrap();
+    let mut game = elikar::init().unwrap();
 
     game.window_builder().build().unwrap();
 
     let events = game.events(); 
     game.spawn_local(async move{
         let mut quit = events.on_quit();
-        let world = quit.world();
         if let Some(_) = quit.next().await {
-            let world = world.read();
-            let mut states = world.resource_write::<States>().unwrap();
-            states.quit();
+            events.elikar_world().quit();
         }
     });
 
