@@ -1,6 +1,5 @@
 use crate::common::{from_sdl_string, Result, SdlError};
 use sdl2_sys::*;
-use xecs::resource::Resource;
 use std::ffi::CString;
 use std::marker::PhantomData;
 use std::os::raw::{c_char, c_int, c_void};
@@ -11,8 +10,6 @@ pub struct Clipboard {
     _marker : PhantomData<()>
 }
 
-impl Resource for Clipboard {}
-
 impl Clipboard {
     pub(in crate) fn new() -> Clipboard {
         Clipboard {
