@@ -1,5 +1,5 @@
 use crate::clipboard::Clipboard;
-use crate::common::{SdlError, Spawner};
+use crate::common::{Handle, SdlError, Spawner};
 use crate::events::Events;
 use crate::events::enter_frame::EnterFrameInner;
 use crate::events::leave_frame::LeaveFrameInner;
@@ -9,25 +9,27 @@ use crate::ime::IME;
 use crate::keyboard::Keyboard;
 use crate::mouse::Mouse;
 use crate::sysinfo::SystemInfo;
-use crate::window;
-use futures::Future;
-use futures::executor::{LocalPool, ThreadPool};
-use futures::task::{LocalSpawnExt, SpawnExt};
+use crate::{quit, time, window};
+use futures::{Future, FutureExt};
+use futures::executor::LocalPool;
+use futures::task::LocalSpawnExt;
 use log::{error, info, trace};
 use parking_lot::RwLock;
 use sdl2_sys::*;
+use tokio::runtime::Runtime;
+use tokio_util::context::TokioContext;
 use xecs::world::World;
 use std::error::Error;
 use std::fmt::{Display, Formatter};
 use std::sync::Arc;
-use std::time::{Duration, Instant};
-pub use self::states::States;
 
-mod states;
+mod world;
+
+pub use world::ElikarWorld;
 
 pub struct Elikar {
     local_pool : LocalPool,
-    thread_pool : ThreadPool,
+    tokio_runtime : Runtime,
     events : Events,
     world : Arc<RwLock<World>>,
 }
@@ -111,7 +113,7 @@ impl Error for SdlInitError {
 
 
 impl Elikar {
-    pub fn new() -> Result<Elikar, SdlInitError> {
+    pub(in crate) fn new() -> Result<Elikar, SdlInitError> {
         info!(target: "Elikar","Initializing Elikar");
         // if unsafe { SDL_InitSubSystem(SDL_INIT_TIMER) } != 0 {
         //     return Err(SdlInitError::Timer(get_error()));
@@ -147,18 +149,23 @@ impl Elikar {
 
         // Pre-store some resource
         trace!(target: "Elikar","Register elikar resources");
-        world.register_resource(States::new());
         world.register_resource(Mouse::new());
         world.register_resource(Keyboard::new());
         world.register_resource(Clipboard::new());
         world.register_resource(SystemInfo::new());
         world.register_resource(IME::new());
+        world.register_resource(quit::Quit::new());
+        world.register_resource(time::Time::new());
 
         let world = Arc::new(RwLock::new(world));
         let events = Events::from_world(world.clone());
+        let runtime = tokio::runtime::Builder::new_multi_thread()
+            .enable_all()
+            .build()
+            .unwrap();
         Ok(Elikar {
             local_pool: LocalPool::new(),
-            thread_pool: ThreadPool::new().unwrap(),
+            tokio_runtime: runtime,
             events,
             world,
         })
@@ -168,6 +175,10 @@ impl Elikar {
         self.world.clone()
     }
 
+    pub fn elikar_world(&self) -> ElikarWorld<'_> {
+        ElikarWorld::new(self.world.read())
+    }
+
     pub fn events(&self) -> Events {
         self.events.clone()
     }
@@ -181,18 +192,16 @@ impl Elikar {
         let events = self.events();
         // as least run all future once to register their waker to World
         self.local_pool.run_until_stalled();
-        let mut frame = 1;
         'mainloop : loop {
-            let start_time = Instant::now();
-            // Quit checking
-            {
-                let world = self.world.read();
-                if world.resource_read::<States>()
-                    .expect("Elikar run(): Game states was moved unexpectly")
-                    .quit {
+            // Quit checking & Get frame counter
+            let frame = {
+                let world = self.elikar_world();
+                if world.need_quit() {
                     break 'mainloop;
                 }
-            }
+                let frame = world.time().frame_counter() as u32;
+                frame
+            };
             // enter frame
             {
                 let world = self.world.read();
@@ -234,32 +243,30 @@ impl Elikar {
             self.local_pool.run_until_stalled();
             // update elikar state
             {
-                let world = self.world.read();
-                let mut states = world.resource_write::<States>().unwrap();
-                states.frame_counter += 1;
-                if states.sec_timer.elapsed() > Duration::from_secs(1) {
-                    states.frames_in_sec = states.frame_counter;
-                    states.frame_counter = 0;
-                    states.sec_timer = Instant::now();
-                }
-                states.last_frame_time = start_time.elapsed();
+                let world = self.elikar_world();
+                world.time_mut().tick();
             }
-            frame += 1;
         }
     }
 }
 
 impl Spawner for Elikar {
-    fn spawn<F>(&mut self,f : F)
+    fn spawn<F>(&mut self,f : F) -> Handle
     where F : Future<Output = ()> + Send + 'static {
         info!(target: "Elikar","Spawn an async task");
-        self.thread_pool.spawn(f).unwrap();
+        let handle = self.tokio_runtime.spawn(f);
+        Handle::tokio(handle)
     }
 
-    fn spawn_local<F>(&mut self,f : F)
+    fn spawn_local<F>(&mut self,f : F) -> Handle
     where F : Future<Output = ()> + 'static {
-        info!(target: "Elikar","Spawn a lock task");
-        self.local_pool.spawner().spawn_local(f).unwrap();
+        info!(target: "Elikar","Spawn a local task");
+        let (f,abort_handle) = futures::future::abortable(f);
+        let rt_handle = self.tokio_runtime.handle().clone();
+        let task_handle = self.local_pool.spawner()
+            .spawn_local_with_handle(TokioContext::new(f.map(|_|()),rt_handle))
+            .unwrap();
+        Handle::futures(abort_handle, task_handle)
     }
 }
 
