@@ -1,5 +1,5 @@
 use std::sync::Arc;
-use crate::{drop_file, ime, keyboard, mouse, window::{self, find_window}};
+use crate::{ElikarWorld, drop_file, ime, keyboard, mouse, window::{self, find_window}};
 use parking_lot::RwLock;
 use xecs::world::World;
 use self::quit::QuitEvent;
@@ -172,6 +172,10 @@ impl Events {
         self.world.clone()
     }
 
+    pub fn elikar_world(&self) -> ElikarWorld<'_> {
+        ElikarWorld::new(self.world.read())
+    }
+
     pub fn on_quit(&self) -> Quit {
         Quit::from_world(self.world.clone())
     }
