@@ -2,15 +2,13 @@ use std::{pin::Pin, sync::Arc, task::{Context, Poll, Waker}};
 use crossbeam::channel::{Receiver, Sender, unbounded};
 use futures::Stream;
 use parking_lot::RwLock;
-use xecs::{component::Component, entity::EntityId, system::System, world::World};
+use xecs::{entity::EntityId, system::System, world::World};
 
 pub(in super) struct QuitEvent {
     pub(in super) tx : Sender<()>,
     pub(in super) waker : Waker
 }
 
-impl Component for QuitEvent {}
-
 pub struct Quit {
     world : Arc<RwLock<World>>,
     rx : Option<(EntityId,Receiver<()>)>,
